@@ -6,9 +6,9 @@ class ModelAccuraciesRepository:
         self.db = self.con.clientsDB
         self.models = self.db.models
 
-    def add_model_accuracy(self, accuracy, time):
-        self.clients.insert_one({'accuracy': accuracy, 'time': time})
+    def add_model_accuracy(self, accuracy, time, clients):
+        self.models.insert_one({'accuracy': accuracy, 'time': time, 'clients': clients})
 
     def get_clients_accuracies(self):
-        accuracies = [(model['accuracy'], model['time']) for model in self.models.find()]
+        accuracies = [(model['accuracy'], model['time'], model['clients']) for model in self.models.find()]
         return accuracies
